==> libvoikko_4.0.1.orig.tar.gz: libvoikko-4.0.1/src/spellchecker/VfstSuggestion.hpp <==
/* The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 * 
 * The Original Code is Libvoikko: Library of natural language processing tools.
 * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
 * Portions created by the Initial Developer are Copyright (C) 2015
 * the Initial Developer. All Rights Reserved.
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *********************************************************************************/

#ifndef VOIKKO_SPELLCHECKER_VFST_SUGGESTION
#define VOIKKO_SPELLCHECKER_VFST_SUGGESTION

#include <string>
#include "fst/WeightedTransducer.hpp"
#include "setup/DictionaryException.hpp"
#include "setup/setup.hpp"
#include "spellchecker/suggestion/SuggestionStatus.hpp"
#include "spellchecker/suggestion/SuggestionGenerator.hpp"

namespace libvoikko { namespace spellchecker { namespace suggestion {

/**
 * Suggestion generator that uses two weighted VFST transducers (acceptor and error model)
 */
class VfstSuggestion : public SuggestionGenerator {
	public:
		VfstSuggestion(const fst::WeightedTransducer * acceptor, const std::string & directoryName) throw(setup::DictionaryException);
		void generate(SuggestionStatus * s) const;
		void terminate();

	private:
		const fst::WeightedTransducer * acceptor;
		fst::WeightedTransducer * errorModel;
		fst::WeightedConfiguration * acceptorConf;
		fst::WeightedConfiguration * errorModelConf;
		char * acceptorBuffer;
		char * errorModelBuffer;
};

} } }

#endif

==> libvoikko_4.1.orig.tar.gz: libvoikko-4.1/src/spellchecker/VfstSuggestion.hpp <==
/* The contents of this file are subject to the Mozilla Public License Version 
 * 1.1 (the "License"); you may not use this file except in compliance with 
 * the License. You may obtain a copy of the License at 
 * http://www.mozilla.org/MPL/
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 * 
 * The Original Code is Libvoikko: Library of natural language processing tools.
 * The Initial Developer of the Original Code is Harri Pitkänen <hatapitk@iki.fi>.
 * Portions created by the Initial Developer are Copyright (C) 2015
 * the Initial Developer. All Rights Reserved.
 * 
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *********************************************************************************/

#ifndef VOIKKO_SPELLCHECKER_VFST_SUGGESTION
#define VOIKKO_SPELLCHECKER_VFST_SUGGESTION

#include <string>
#include "fst/WeightedTransducer.hpp"
#include "setup/DictionaryException.hpp"
#include "setup/setup.hpp"
#include "spellchecker/suggestion/SuggestionStatus.hpp"
#include "spellchecker/suggestion/SuggestionGenerator.hpp"

namespace libvoikko { namespace spellchecker { namespace suggestion {

/**
 * Suggestion generator that uses two weighted VFST transducers (acceptor and error model)
 */
class VfstSuggestion : public SuggestionGenerator {
	public:
		VfstSuggestion(const fst::WeightedTransducer * acceptor, const std::string & directoryName) throw(setup::DictionaryException);
		void generate(SuggestionStatus * s) const;
		void terminate();

	private:
		const fst::WeightedTransducer * acceptor;
		fst::WeightedTransducer * errorModel;
		fst::WeightedConfiguration * acceptorConf;
		fst::WeightedConfiguration * errorModelConf;
		wchar_t * acceptorBuffer;
		wchar_t * errorModelBuffer;
};

} } }

#endif
